# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AccountArgs', 'Account']

@pulumi.input_type
class AccountArgs:
    def __init__(__self__, *,
                 account: pulumi.Input[builtins.str],
                 account_type: pulumi.Input[builtins.str],
                 db_instance_id: pulumi.Input[builtins.str],
                 password: pulumi.Input[builtins.str],
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 dml_auth_setting: Optional[pulumi.Input['AccountDmlAuthSettingArgs']] = None):
        """
        The set of arguments for constructing a Account resource.
        :param pulumi.Input[builtins.str] account: The name of the database account.
        :param pulumi.Input[builtins.str] account_type: The type of the database account. Valid values:
               - `NormalAccount`: Normal account number.
               - `SuperAccount`: The privileged account.
        :param pulumi.Input[builtins.str] db_instance_id: The cluster ID.
        :param pulumi.Input[builtins.str] password: Database account password. Set the following rules.
               - Consists of at least three of uppercase letters, lowercase letters, numbers, and special characters.
               - Oh-! @#$%^& *()_+-= is a special character.
               - Length is 8~32 characters.
        :param pulumi.Input[builtins.str] description: Note information.
        :param pulumi.Input['AccountDmlAuthSettingArgs'] dml_auth_setting: Authorization information. See `dml_auth_setting` below.
        """
        pulumi.set(__self__, "account", account)
        pulumi.set(__self__, "account_type", account_type)
        pulumi.set(__self__, "db_instance_id", db_instance_id)
        pulumi.set(__self__, "password", password)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if dml_auth_setting is not None:
            pulumi.set(__self__, "dml_auth_setting", dml_auth_setting)

    @property
    @pulumi.getter
    def account(self) -> pulumi.Input[builtins.str]:
        """
        The name of the database account.
        """
        return pulumi.get(self, "account")

    @account.setter
    def account(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "account", value)

    @property
    @pulumi.getter(name="accountType")
    def account_type(self) -> pulumi.Input[builtins.str]:
        """
        The type of the database account. Valid values:
        - `NormalAccount`: Normal account number.
        - `SuperAccount`: The privileged account.
        """
        return pulumi.get(self, "account_type")

    @account_type.setter
    def account_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "account_type", value)

    @property
    @pulumi.getter(name="dbInstanceId")
    def db_instance_id(self) -> pulumi.Input[builtins.str]:
        """
        The cluster ID.
        """
        return pulumi.get(self, "db_instance_id")

    @db_instance_id.setter
    def db_instance_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "db_instance_id", value)

    @property
    @pulumi.getter
    def password(self) -> pulumi.Input[builtins.str]:
        """
        Database account password. Set the following rules.
        - Consists of at least three of uppercase letters, lowercase letters, numbers, and special characters.
        - Oh-! @#$%^& *()_+-= is a special character.
        - Length is 8~32 characters.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Note information.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="dmlAuthSetting")
    def dml_auth_setting(self) -> Optional[pulumi.Input['AccountDmlAuthSettingArgs']]:
        """
        Authorization information. See `dml_auth_setting` below.
        """
        return pulumi.get(self, "dml_auth_setting")

    @dml_auth_setting.setter
    def dml_auth_setting(self, value: Optional[pulumi.Input['AccountDmlAuthSettingArgs']]):
        pulumi.set(self, "dml_auth_setting", value)


@pulumi.input_type
class _AccountState:
    def __init__(__self__, *,
                 account: Optional[pulumi.Input[builtins.str]] = None,
                 account_type: Optional[pulumi.Input[builtins.str]] = None,
                 db_instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 dml_auth_setting: Optional[pulumi.Input['AccountDmlAuthSettingArgs']] = None,
                 password: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Account resources.
        :param pulumi.Input[builtins.str] account: The name of the database account.
        :param pulumi.Input[builtins.str] account_type: The type of the database account. Valid values:
               - `NormalAccount`: Normal account number.
               - `SuperAccount`: The privileged account.
        :param pulumi.Input[builtins.str] db_instance_id: The cluster ID.
        :param pulumi.Input[builtins.str] description: Note information.
        :param pulumi.Input['AccountDmlAuthSettingArgs'] dml_auth_setting: Authorization information. See `dml_auth_setting` below.
        :param pulumi.Input[builtins.str] password: Database account password. Set the following rules.
               - Consists of at least three of uppercase letters, lowercase letters, numbers, and special characters.
               - Oh-! @#$%^& *()_+-= is a special character.
               - Length is 8~32 characters.
        """
        if account is not None:
            pulumi.set(__self__, "account", account)
        if account_type is not None:
            pulumi.set(__self__, "account_type", account_type)
        if db_instance_id is not None:
            pulumi.set(__self__, "db_instance_id", db_instance_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if dml_auth_setting is not None:
            pulumi.set(__self__, "dml_auth_setting", dml_auth_setting)
        if password is not None:
            pulumi.set(__self__, "password", password)

    @property
    @pulumi.getter
    def account(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the database account.
        """
        return pulumi.get(self, "account")

    @account.setter
    def account(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account", value)

    @property
    @pulumi.getter(name="accountType")
    def account_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The type of the database account. Valid values:
        - `NormalAccount`: Normal account number.
        - `SuperAccount`: The privileged account.
        """
        return pulumi.get(self, "account_type")

    @account_type.setter
    def account_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_type", value)

    @property
    @pulumi.getter(name="dbInstanceId")
    def db_instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The cluster ID.
        """
        return pulumi.get(self, "db_instance_id")

    @db_instance_id.setter
    def db_instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "db_instance_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Note information.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="dmlAuthSetting")
    def dml_auth_setting(self) -> Optional[pulumi.Input['AccountDmlAuthSettingArgs']]:
        """
        Authorization information. See `dml_auth_setting` below.
        """
        return pulumi.get(self, "dml_auth_setting")

    @dml_auth_setting.setter
    def dml_auth_setting(self, value: Optional[pulumi.Input['AccountDmlAuthSettingArgs']]):
        pulumi.set(self, "dml_auth_setting", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Database account password. Set the following rules.
        - Consists of at least three of uppercase letters, lowercase letters, numbers, and special characters.
        - Oh-! @#$%^& *()_+-= is a special character.
        - Length is 8~32 characters.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "password", value)


@pulumi.type_token("alicloud:clickhouseenterprisedbcluster/account:Account")
class Account(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account: Optional[pulumi.Input[builtins.str]] = None,
                 account_type: Optional[pulumi.Input[builtins.str]] = None,
                 db_instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 dml_auth_setting: Optional[pulumi.Input[Union['AccountDmlAuthSettingArgs', 'AccountDmlAuthSettingArgsDict']]] = None,
                 password: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a Click House Enterprise Db Cluster Account resource.

        Clickhouse enterprise instance account.

        For information about Click House Enterprise Db Cluster Account and how to use it, see [What is Enterprise Db Cluster Account](https://next.api.alibabacloud.com/document/clickhouse/2023-05-22/CreateAccount).

        > **NOTE:** Available since v1.247.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        region_id = config.get("regionId")
        if region_id is None:
            region_id = "cn-beijing"
        vsw_ip_range_i = config.get("vswIpRangeI")
        if vsw_ip_range_i is None:
            vsw_ip_range_i = "172.16.1.0/24"
        vpc_ip_range = config.get("vpcIpRange")
        if vpc_ip_range is None:
            vpc_ip_range = "172.16.0.0/12"
        zone_id_i = config.get("zoneIdI")
        if zone_id_i is None:
            zone_id_i = "cn-beijing-i"
        defaultkt_k_lu_m = alicloud.vpc.Network("defaultktKLuM", cidr_block=vpc_ip_range)
        default_tqwn3k = alicloud.vpc.Switch("defaultTQWN3k",
            vpc_id=defaultkt_k_lu_m.id,
            zone_id=zone_id_i,
            cidr_block=vsw_ip_range_i)
        default_wrov_od = alicloud.clickhouseenterprisedbcluster.ClickHouseEnterpriseDbCluster("defaultWrovOd",
            zone_id=zone_id_i,
            vpc_id=defaultkt_k_lu_m.id,
            scale_min="8",
            scale_max="16",
            vswitch_id=default_tqwn3k.id)
        default = alicloud.clickhouseenterprisedbcluster.Account("default",
            account="abc",
            description="example_desc",
            db_instance_id=default_wrov_od.id,
            account_type="NormalAccount",
            password="abc123456!",
            dml_auth_setting={
                "dml_authority": 0,
                "ddl_authority": True,
                "allow_dictionaries": ["*"],
                "allow_databases": ["*"],
            })
        ```

        ## Import

        Click House Enterprise Db Cluster Account can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:clickhouseenterprisedbcluster/account:Account example <db_instance_id>:<account>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] account: The name of the database account.
        :param pulumi.Input[builtins.str] account_type: The type of the database account. Valid values:
               - `NormalAccount`: Normal account number.
               - `SuperAccount`: The privileged account.
        :param pulumi.Input[builtins.str] db_instance_id: The cluster ID.
        :param pulumi.Input[builtins.str] description: Note information.
        :param pulumi.Input[Union['AccountDmlAuthSettingArgs', 'AccountDmlAuthSettingArgsDict']] dml_auth_setting: Authorization information. See `dml_auth_setting` below.
        :param pulumi.Input[builtins.str] password: Database account password. Set the following rules.
               - Consists of at least three of uppercase letters, lowercase letters, numbers, and special characters.
               - Oh-! @#$%^& *()_+-= is a special character.
               - Length is 8~32 characters.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AccountArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Click House Enterprise Db Cluster Account resource.

        Clickhouse enterprise instance account.

        For information about Click House Enterprise Db Cluster Account and how to use it, see [What is Enterprise Db Cluster Account](https://next.api.alibabacloud.com/document/clickhouse/2023-05-22/CreateAccount).

        > **NOTE:** Available since v1.247.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        region_id = config.get("regionId")
        if region_id is None:
            region_id = "cn-beijing"
        vsw_ip_range_i = config.get("vswIpRangeI")
        if vsw_ip_range_i is None:
            vsw_ip_range_i = "172.16.1.0/24"
        vpc_ip_range = config.get("vpcIpRange")
        if vpc_ip_range is None:
            vpc_ip_range = "172.16.0.0/12"
        zone_id_i = config.get("zoneIdI")
        if zone_id_i is None:
            zone_id_i = "cn-beijing-i"
        defaultkt_k_lu_m = alicloud.vpc.Network("defaultktKLuM", cidr_block=vpc_ip_range)
        default_tqwn3k = alicloud.vpc.Switch("defaultTQWN3k",
            vpc_id=defaultkt_k_lu_m.id,
            zone_id=zone_id_i,
            cidr_block=vsw_ip_range_i)
        default_wrov_od = alicloud.clickhouseenterprisedbcluster.ClickHouseEnterpriseDbCluster("defaultWrovOd",
            zone_id=zone_id_i,
            vpc_id=defaultkt_k_lu_m.id,
            scale_min="8",
            scale_max="16",
            vswitch_id=default_tqwn3k.id)
        default = alicloud.clickhouseenterprisedbcluster.Account("default",
            account="abc",
            description="example_desc",
            db_instance_id=default_wrov_od.id,
            account_type="NormalAccount",
            password="abc123456!",
            dml_auth_setting={
                "dml_authority": 0,
                "ddl_authority": True,
                "allow_dictionaries": ["*"],
                "allow_databases": ["*"],
            })
        ```

        ## Import

        Click House Enterprise Db Cluster Account can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:clickhouseenterprisedbcluster/account:Account example <db_instance_id>:<account>
        ```

        :param str resource_name: The name of the resource.
        :param AccountArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AccountArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account: Optional[pulumi.Input[builtins.str]] = None,
                 account_type: Optional[pulumi.Input[builtins.str]] = None,
                 db_instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 dml_auth_setting: Optional[pulumi.Input[Union['AccountDmlAuthSettingArgs', 'AccountDmlAuthSettingArgsDict']]] = None,
                 password: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AccountArgs.__new__(AccountArgs)

            if account is None and not opts.urn:
                raise TypeError("Missing required property 'account'")
            __props__.__dict__["account"] = account
            if account_type is None and not opts.urn:
                raise TypeError("Missing required property 'account_type'")
            __props__.__dict__["account_type"] = account_type
            if db_instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'db_instance_id'")
            __props__.__dict__["db_instance_id"] = db_instance_id
            __props__.__dict__["description"] = description
            __props__.__dict__["dml_auth_setting"] = dml_auth_setting
            if password is None and not opts.urn:
                raise TypeError("Missing required property 'password'")
            __props__.__dict__["password"] = None if password is None else pulumi.Output.secret(password)
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["password"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(Account, __self__).__init__(
            'alicloud:clickhouseenterprisedbcluster/account:Account',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account: Optional[pulumi.Input[builtins.str]] = None,
            account_type: Optional[pulumi.Input[builtins.str]] = None,
            db_instance_id: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            dml_auth_setting: Optional[pulumi.Input[Union['AccountDmlAuthSettingArgs', 'AccountDmlAuthSettingArgsDict']]] = None,
            password: Optional[pulumi.Input[builtins.str]] = None) -> 'Account':
        """
        Get an existing Account resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] account: The name of the database account.
        :param pulumi.Input[builtins.str] account_type: The type of the database account. Valid values:
               - `NormalAccount`: Normal account number.
               - `SuperAccount`: The privileged account.
        :param pulumi.Input[builtins.str] db_instance_id: The cluster ID.
        :param pulumi.Input[builtins.str] description: Note information.
        :param pulumi.Input[Union['AccountDmlAuthSettingArgs', 'AccountDmlAuthSettingArgsDict']] dml_auth_setting: Authorization information. See `dml_auth_setting` below.
        :param pulumi.Input[builtins.str] password: Database account password. Set the following rules.
               - Consists of at least three of uppercase letters, lowercase letters, numbers, and special characters.
               - Oh-! @#$%^& *()_+-= is a special character.
               - Length is 8~32 characters.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AccountState.__new__(_AccountState)

        __props__.__dict__["account"] = account
        __props__.__dict__["account_type"] = account_type
        __props__.__dict__["db_instance_id"] = db_instance_id
        __props__.__dict__["description"] = description
        __props__.__dict__["dml_auth_setting"] = dml_auth_setting
        __props__.__dict__["password"] = password
        return Account(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def account(self) -> pulumi.Output[builtins.str]:
        """
        The name of the database account.
        """
        return pulumi.get(self, "account")

    @property
    @pulumi.getter(name="accountType")
    def account_type(self) -> pulumi.Output[builtins.str]:
        """
        The type of the database account. Valid values:
        - `NormalAccount`: Normal account number.
        - `SuperAccount`: The privileged account.
        """
        return pulumi.get(self, "account_type")

    @property
    @pulumi.getter(name="dbInstanceId")
    def db_instance_id(self) -> pulumi.Output[builtins.str]:
        """
        The cluster ID.
        """
        return pulumi.get(self, "db_instance_id")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Note information.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="dmlAuthSetting")
    def dml_auth_setting(self) -> pulumi.Output[Optional['outputs.AccountDmlAuthSetting']]:
        """
        Authorization information. See `dml_auth_setting` below.
        """
        return pulumi.get(self, "dml_auth_setting")

    @property
    @pulumi.getter
    def password(self) -> pulumi.Output[builtins.str]:
        """
        Database account password. Set the following rules.
        - Consists of at least three of uppercase letters, lowercase letters, numbers, and special characters.
        - Oh-! @#$%^& *()_+-= is a special character.
        - Length is 8~32 characters.
        """
        return pulumi.get(self, "password")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ClusterArgs', 'Cluster']

@pulumi.input_type
class ClusterArgs:
    def __init__(__self__, *,
                 cluster_description: Optional[pulumi.Input[builtins.str]] = None,
                 cluster_name: Optional[pulumi.Input[builtins.str]] = None,
                 cluster_type: Optional[pulumi.Input[builtins.str]] = None,
                 components: Optional[pulumi.Input[Sequence[pulumi.Input['ClusterComponentArgs']]]] = None,
                 hpn_zone: Optional[pulumi.Input[builtins.str]] = None,
                 ignore_failed_node_tasks: Optional[pulumi.Input[builtins.bool]] = None,
                 networks: Optional[pulumi.Input['ClusterNetworksArgs']] = None,
                 nimiz_vswitches: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 node_groups: Optional[pulumi.Input[Sequence[pulumi.Input['ClusterNodeGroupArgs']]]] = None,
                 open_eni_jumbo_frame: Optional[pulumi.Input[builtins.bool]] = None,
                 resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None):
        """
        The set of arguments for constructing a Cluster resource.
        :param pulumi.Input[builtins.str] cluster_description: cluster description
        :param pulumi.Input[builtins.str] cluster_name: ClusterName
        :param pulumi.Input[builtins.str] cluster_type: cluster type
        :param pulumi.Input[Sequence[pulumi.Input['ClusterComponentArgs']]] components: Component (software instance) See `components` below.
        :param pulumi.Input[builtins.str] hpn_zone: Cluster Number
        :param pulumi.Input[builtins.bool] ignore_failed_node_tasks: Whether to allow skipping failed nodes. Default value: False
        :param pulumi.Input['ClusterNetworksArgs'] networks: Network Information See `networks` below.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] nimiz_vswitches: Node virtual switch
        :param pulumi.Input[Sequence[pulumi.Input['ClusterNodeGroupArgs']]] node_groups: Node Group List See `node_groups` below.
        :param pulumi.Input[builtins.bool] open_eni_jumbo_frame: Whether the network interface supports jumbo frames
        :param pulumi.Input[builtins.str] resource_group_id: The ID of the resource group
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: tag
        """
        if cluster_description is not None:
            pulumi.set(__self__, "cluster_description", cluster_description)
        if cluster_name is not None:
            pulumi.set(__self__, "cluster_name", cluster_name)
        if cluster_type is not None:
            pulumi.set(__self__, "cluster_type", cluster_type)
        if components is not None:
            pulumi.set(__self__, "components", components)
        if hpn_zone is not None:
            pulumi.set(__self__, "hpn_zone", hpn_zone)
        if ignore_failed_node_tasks is not None:
            pulumi.set(__self__, "ignore_failed_node_tasks", ignore_failed_node_tasks)
        if networks is not None:
            pulumi.set(__self__, "networks", networks)
        if nimiz_vswitches is not None:
            pulumi.set(__self__, "nimiz_vswitches", nimiz_vswitches)
        if node_groups is not None:
            pulumi.set(__self__, "node_groups", node_groups)
        if open_eni_jumbo_frame is not None:
            pulumi.set(__self__, "open_eni_jumbo_frame", open_eni_jumbo_frame)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="clusterDescription")
    def cluster_description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        cluster description
        """
        return pulumi.get(self, "cluster_description")

    @cluster_description.setter
    def cluster_description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cluster_description", value)

    @property
    @pulumi.getter(name="clusterName")
    def cluster_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        ClusterName
        """
        return pulumi.get(self, "cluster_name")

    @cluster_name.setter
    def cluster_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cluster_name", value)

    @property
    @pulumi.getter(name="clusterType")
    def cluster_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        cluster type
        """
        return pulumi.get(self, "cluster_type")

    @cluster_type.setter
    def cluster_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cluster_type", value)

    @property
    @pulumi.getter
    def components(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ClusterComponentArgs']]]]:
        """
        Component (software instance) See `components` below.
        """
        return pulumi.get(self, "components")

    @components.setter
    def components(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ClusterComponentArgs']]]]):
        pulumi.set(self, "components", value)

    @property
    @pulumi.getter(name="hpnZone")
    def hpn_zone(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Cluster Number
        """
        return pulumi.get(self, "hpn_zone")

    @hpn_zone.setter
    def hpn_zone(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "hpn_zone", value)

    @property
    @pulumi.getter(name="ignoreFailedNodeTasks")
    def ignore_failed_node_tasks(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to allow skipping failed nodes. Default value: False
        """
        return pulumi.get(self, "ignore_failed_node_tasks")

    @ignore_failed_node_tasks.setter
    def ignore_failed_node_tasks(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "ignore_failed_node_tasks", value)

    @property
    @pulumi.getter
    def networks(self) -> Optional[pulumi.Input['ClusterNetworksArgs']]:
        """
        Network Information See `networks` below.
        """
        return pulumi.get(self, "networks")

    @networks.setter
    def networks(self, value: Optional[pulumi.Input['ClusterNetworksArgs']]):
        pulumi.set(self, "networks", value)

    @property
    @pulumi.getter(name="nimizVswitches")
    def nimiz_vswitches(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        Node virtual switch
        """
        return pulumi.get(self, "nimiz_vswitches")

    @nimiz_vswitches.setter
    def nimiz_vswitches(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "nimiz_vswitches", value)

    @property
    @pulumi.getter(name="nodeGroups")
    def node_groups(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ClusterNodeGroupArgs']]]]:
        """
        Node Group List See `node_groups` below.
        """
        return pulumi.get(self, "node_groups")

    @node_groups.setter
    def node_groups(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ClusterNodeGroupArgs']]]]):
        pulumi.set(self, "node_groups", value)

    @property
    @pulumi.getter(name="openEniJumboFrame")
    def open_eni_jumbo_frame(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether the network interface supports jumbo frames
        """
        return pulumi.get(self, "open_eni_jumbo_frame")

    @open_eni_jumbo_frame.setter
    def open_eni_jumbo_frame(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "open_eni_jumbo_frame", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the resource group
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        tag
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _ClusterState:
    def __init__(__self__, *,
                 cluster_description: Optional[pulumi.Input[builtins.str]] = None,
                 cluster_name: Optional[pulumi.Input[builtins.str]] = None,
                 cluster_type: Optional[pulumi.Input[builtins.str]] = None,
                 components: Optional[pulumi.Input[Sequence[pulumi.Input['ClusterComponentArgs']]]] = None,
                 create_time: Optional[pulumi.Input[builtins.str]] = None,
                 hpn_zone: Optional[pulumi.Input[builtins.str]] = None,
                 ignore_failed_node_tasks: Optional[pulumi.Input[builtins.bool]] = None,
                 networks: Optional[pulumi.Input['ClusterNetworksArgs']] = None,
                 nimiz_vswitches: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 node_groups: Optional[pulumi.Input[Sequence[pulumi.Input['ClusterNodeGroupArgs']]]] = None,
                 open_eni_jumbo_frame: Optional[pulumi.Input[builtins.bool]] = None,
                 resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering Cluster resources.
        :param pulumi.Input[builtins.str] cluster_description: cluster description
        :param pulumi.Input[builtins.str] cluster_name: ClusterName
        :param pulumi.Input[builtins.str] cluster_type: cluster type
        :param pulumi.Input[Sequence[pulumi.Input['ClusterComponentArgs']]] components: Component (software instance) See `components` below.
        :param pulumi.Input[builtins.str] create_time: The creation time of the resource
        :param pulumi.Input[builtins.str] hpn_zone: Cluster Number
        :param pulumi.Input[builtins.bool] ignore_failed_node_tasks: Whether to allow skipping failed nodes. Default value: False
        :param pulumi.Input['ClusterNetworksArgs'] networks: Network Information See `networks` below.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] nimiz_vswitches: Node virtual switch
        :param pulumi.Input[Sequence[pulumi.Input['ClusterNodeGroupArgs']]] node_groups: Node Group List See `node_groups` below.
        :param pulumi.Input[builtins.bool] open_eni_jumbo_frame: Whether the network interface supports jumbo frames
        :param pulumi.Input[builtins.str] resource_group_id: The ID of the resource group
        :param pulumi.Input[builtins.str] status: The status of the resource
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: tag
        """
        if cluster_description is not None:
            pulumi.set(__self__, "cluster_description", cluster_description)
        if cluster_name is not None:
            pulumi.set(__self__, "cluster_name", cluster_name)
        if cluster_type is not None:
            pulumi.set(__self__, "cluster_type", cluster_type)
        if components is not None:
            pulumi.set(__self__, "components", components)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if hpn_zone is not None:
            pulumi.set(__self__, "hpn_zone", hpn_zone)
        if ignore_failed_node_tasks is not None:
            pulumi.set(__self__, "ignore_failed_node_tasks", ignore_failed_node_tasks)
        if networks is not None:
            pulumi.set(__self__, "networks", networks)
        if nimiz_vswitches is not None:
            pulumi.set(__self__, "nimiz_vswitches", nimiz_vswitches)
        if node_groups is not None:
            pulumi.set(__self__, "node_groups", node_groups)
        if open_eni_jumbo_frame is not None:
            pulumi.set(__self__, "open_eni_jumbo_frame", open_eni_jumbo_frame)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="clusterDescription")
    def cluster_description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        cluster description
        """
        return pulumi.get(self, "cluster_description")

    @cluster_description.setter
    def cluster_description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cluster_description", value)

    @property
    @pulumi.getter(name="clusterName")
    def cluster_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        ClusterName
        """
        return pulumi.get(self, "cluster_name")

    @cluster_name.setter
    def cluster_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cluster_name", value)

    @property
    @pulumi.getter(name="clusterType")
    def cluster_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        cluster type
        """
        return pulumi.get(self, "cluster_type")

    @cluster_type.setter
    def cluster_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cluster_type", value)

    @property
    @pulumi.getter
    def components(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ClusterComponentArgs']]]]:
        """
        Component (software instance) See `components` below.
        """
        return pulumi.get(self, "components")

    @components.setter
    def components(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ClusterComponentArgs']]]]):
        pulumi.set(self, "components", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The creation time of the resource
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="hpnZone")
    def hpn_zone(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Cluster Number
        """
        return pulumi.get(self, "hpn_zone")

    @hpn_zone.setter
    def hpn_zone(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "hpn_zone", value)

    @property
    @pulumi.getter(name="ignoreFailedNodeTasks")
    def ignore_failed_node_tasks(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to allow skipping failed nodes. Default value: False
        """
        return pulumi.get(self, "ignore_failed_node_tasks")

    @ignore_failed_node_tasks.setter
    def ignore_failed_node_tasks(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "ignore_failed_node_tasks", value)

    @property
    @pulumi.getter
    def networks(self) -> Optional[pulumi.Input['ClusterNetworksArgs']]:
        """
        Network Information See `networks` below.
        """
        return pulumi.get(self, "networks")

    @networks.setter
    def networks(self, value: Optional[pulumi.Input['ClusterNetworksArgs']]):
        pulumi.set(self, "networks", value)

    @property
    @pulumi.getter(name="nimizVswitches")
    def nimiz_vswitches(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        Node virtual switch
        """
        return pulumi.get(self, "nimiz_vswitches")

    @nimiz_vswitches.setter
    def nimiz_vswitches(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "nimiz_vswitches", value)

    @property
    @pulumi.getter(name="nodeGroups")
    def node_groups(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ClusterNodeGroupArgs']]]]:
        """
        Node Group List See `node_groups` below.
        """
        return pulumi.get(self, "node_groups")

    @node_groups.setter
    def node_groups(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ClusterNodeGroupArgs']]]]):
        pulumi.set(self, "node_groups", value)

    @property
    @pulumi.getter(name="openEniJumboFrame")
    def open_eni_jumbo_frame(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether the network interface supports jumbo frames
        """
        return pulumi.get(self, "open_eni_jumbo_frame")

    @open_eni_jumbo_frame.setter
    def open_eni_jumbo_frame(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "open_eni_jumbo_frame", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the resource group
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The status of the resource
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        tag
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.type_token("alicloud:eflo/cluster:Cluster")
class Cluster(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_description: Optional[pulumi.Input[builtins.str]] = None,
                 cluster_name: Optional[pulumi.Input[builtins.str]] = None,
                 cluster_type: Optional[pulumi.Input[builtins.str]] = None,
                 components: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ClusterComponentArgs', 'ClusterComponentArgsDict']]]]] = None,
                 hpn_zone: Optional[pulumi.Input[builtins.str]] = None,
                 ignore_failed_node_tasks: Optional[pulumi.Input[builtins.bool]] = None,
                 networks: Optional[pulumi.Input[Union['ClusterNetworksArgs', 'ClusterNetworksArgsDict']]] = None,
                 nimiz_vswitches: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 node_groups: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ClusterNodeGroupArgs', 'ClusterNodeGroupArgsDict']]]]] = None,
                 open_eni_jumbo_frame: Optional[pulumi.Input[builtins.bool]] = None,
                 resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        """
        Provides a Eflo Cluster resource.

        Large computing cluster.

        For information about Eflo Cluster and how to use it, see [What is Cluster](https://next.api.alibabacloud.com/document/eflo-controller/2022-12-15/CreateCluster).

        > **NOTE:** Available since v1.246.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.resourcemanager.get_resource_groups()
        create_vpc = alicloud.vpc.Network("create_vpc",
            cidr_block="192.168.0.0/16",
            vpc_name="cluster-resoure-example")
        create_vswitch = alicloud.vpc.Switch("create_vswitch",
            vpc_id=create_vpc.id,
            zone_id="cn-hangzhou-b",
            cidr_block="192.168.0.0/24",
            vswitch_name="cluster-resoure-example")
        create_security_group = alicloud.ecs.SecurityGroup("create_security_group",
            description="sg",
            security_group_name="cluster-resoure-example",
            security_group_type="normal",
            vpc_id=create_vpc.id)
        default_cluster = alicloud.eflo.Cluster("default",
            cluster_description="cluster-resource-example",
            open_eni_jumbo_frame=False,
            hpn_zone="B1",
            nimiz_vswitches=["1111"],
            ignore_failed_node_tasks=True,
            resource_group_id=default.ids[1],
            node_groups=[{
                "image_id": "i198448731735114628708",
                "zone_id": "cn-hangzhou-b",
                "node_group_name": "cluster-resource-example",
                "node_group_description": "cluster-resource-example",
                "machine_type": "efg2.C48cA3sen",
            }],
            networks={
                "tail_ip_version": "ipv4",
                "new_vpd_info": {
                    "monitor_vpc_id": create_vpc.id,
                    "monitor_vswitch_id": create_vswitch.id,
                    "cen_id": "11111",
                    "cloud_link_id": "1111",
                    "vpd_cidr": "111",
                    "vpd_subnets": [{
                        "zone_id": "1111",
                        "subnet_cidr": "111",
                        "subnet_type": "111",
                    }],
                    "cloud_link_cidr": "169.254.128.0/23",
                },
                "security_group_id": create_security_group.id,
                "vswitch_zone_id": "cn-hangzhou-b",
                "vpc_id": create_vpc.id,
                "vswitch_id": create_vswitch.id,
                "vpd_info": {
                    "vpd_id": "111",
                    "vpd_subnets": ["111"],
                },
                "ip_allocation_policies": [{
                    "bond_policy": {
                        "bond_default_subnet": "111",
                        "bonds": [{
                            "name": "111",
                            "subnet": "111",
                        }],
                    },
                    "machine_type_policies": [{
                        "bonds": [{
                            "name": "111",
                            "subnet": "111",
                        }],
                        "machine_type": "111",
                    }],
                    "node_policies": [{
                        "bonds": [{
                            "name": "111",
                            "subnet": "111",
                        }],
                        "node_id": "111",
                    }],
                }],
            },
            cluster_name="tfacceflo7165",
            cluster_type="Lite")
        ```

        ## Import

        Eflo Cluster can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:eflo/cluster:Cluster example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] cluster_description: cluster description
        :param pulumi.Input[builtins.str] cluster_name: ClusterName
        :param pulumi.Input[builtins.str] cluster_type: cluster type
        :param pulumi.Input[Sequence[pulumi.Input[Union['ClusterComponentArgs', 'ClusterComponentArgsDict']]]] components: Component (software instance) See `components` below.
        :param pulumi.Input[builtins.str] hpn_zone: Cluster Number
        :param pulumi.Input[builtins.bool] ignore_failed_node_tasks: Whether to allow skipping failed nodes. Default value: False
        :param pulumi.Input[Union['ClusterNetworksArgs', 'ClusterNetworksArgsDict']] networks: Network Information See `networks` below.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] nimiz_vswitches: Node virtual switch
        :param pulumi.Input[Sequence[pulumi.Input[Union['ClusterNodeGroupArgs', 'ClusterNodeGroupArgsDict']]]] node_groups: Node Group List See `node_groups` below.
        :param pulumi.Input[builtins.bool] open_eni_jumbo_frame: Whether the network interface supports jumbo frames
        :param pulumi.Input[builtins.str] resource_group_id: The ID of the resource group
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: tag
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[ClusterArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Eflo Cluster resource.

        Large computing cluster.

        For information about Eflo Cluster and how to use it, see [What is Cluster](https://next.api.alibabacloud.com/document/eflo-controller/2022-12-15/CreateCluster).

        > **NOTE:** Available since v1.246.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.resourcemanager.get_resource_groups()
        create_vpc = alicloud.vpc.Network("create_vpc",
            cidr_block="192.168.0.0/16",
            vpc_name="cluster-resoure-example")
        create_vswitch = alicloud.vpc.Switch("create_vswitch",
            vpc_id=create_vpc.id,
            zone_id="cn-hangzhou-b",
            cidr_block="192.168.0.0/24",
            vswitch_name="cluster-resoure-example")
        create_security_group = alicloud.ecs.SecurityGroup("create_security_group",
            description="sg",
            security_group_name="cluster-resoure-example",
            security_group_type="normal",
            vpc_id=create_vpc.id)
        default_cluster = alicloud.eflo.Cluster("default",
            cluster_description="cluster-resource-example",
            open_eni_jumbo_frame=False,
            hpn_zone="B1",
            nimiz_vswitches=["1111"],
            ignore_failed_node_tasks=True,
            resource_group_id=default.ids[1],
            node_groups=[{
                "image_id": "i198448731735114628708",
                "zone_id": "cn-hangzhou-b",
                "node_group_name": "cluster-resource-example",
                "node_group_description": "cluster-resource-example",
                "machine_type": "efg2.C48cA3sen",
            }],
            networks={
                "tail_ip_version": "ipv4",
                "new_vpd_info": {
                    "monitor_vpc_id": create_vpc.id,
                    "monitor_vswitch_id": create_vswitch.id,
                    "cen_id": "11111",
                    "cloud_link_id": "1111",
                    "vpd_cidr": "111",
                    "vpd_subnets": [{
                        "zone_id": "1111",
                        "subnet_cidr": "111",
                        "subnet_type": "111",
                    }],
                    "cloud_link_cidr": "169.254.128.0/23",
                },
                "security_group_id": create_security_group.id,
                "vswitch_zone_id": "cn-hangzhou-b",
                "vpc_id": create_vpc.id,
                "vswitch_id": create_vswitch.id,
                "vpd_info": {
                    "vpd_id": "111",
                    "vpd_subnets": ["111"],
                },
                "ip_allocation_policies": [{
                    "bond_policy": {
                        "bond_default_subnet": "111",
                        "bonds": [{
                            "name": "111",
                            "subnet": "111",
                        }],
                    },
                    "machine_type_policies": [{
                        "bonds": [{
                            "name": "111",
                            "subnet": "111",
                        }],
                        "machine_type": "111",
                    }],
                    "node_policies": [{
                        "bonds": [{
                            "name": "111",
                            "subnet": "111",
                        }],
                        "node_id": "111",
                    }],
                }],
            },
            cluster_name="tfacceflo7165",
            cluster_type="Lite")
        ```

        ## Import

        Eflo Cluster can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:eflo/cluster:Cluster example <id>
        ```

        :param str resource_name: The name of the resource.
        :param ClusterArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ClusterArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_description: Optional[pulumi.Input[builtins.str]] = None,
                 cluster_name: Optional[pulumi.Input[builtins.str]] = None,
                 cluster_type: Optional[pulumi.Input[builtins.str]] = None,
                 components: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ClusterComponentArgs', 'ClusterComponentArgsDict']]]]] = None,
                 hpn_zone: Optional[pulumi.Input[builtins.str]] = None,
                 ignore_failed_node_tasks: Optional[pulumi.Input[builtins.bool]] = None,
                 networks: Optional[pulumi.Input[Union['ClusterNetworksArgs', 'ClusterNetworksArgsDict']]] = None,
                 nimiz_vswitches: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 node_groups: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ClusterNodeGroupArgs', 'ClusterNodeGroupArgsDict']]]]] = None,
                 open_eni_jumbo_frame: Optional[pulumi.Input[builtins.bool]] = None,
                 resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ClusterArgs.__new__(ClusterArgs)

            __props__.__dict__["cluster_description"] = cluster_description
            __props__.__dict__["cluster_name"] = cluster_name
            __props__.__dict__["cluster_type"] = cluster_type
            __props__.__dict__["components"] = components
            __props__.__dict__["hpn_zone"] = hpn_zone
            __props__.__dict__["ignore_failed_node_tasks"] = ignore_failed_node_tasks
            __props__.__dict__["networks"] = networks
            __props__.__dict__["nimiz_vswitches"] = nimiz_vswitches
            __props__.__dict__["node_groups"] = node_groups
            __props__.__dict__["open_eni_jumbo_frame"] = open_eni_jumbo_frame
            __props__.__dict__["resource_group_id"] = resource_group_id
            __props__.__dict__["tags"] = tags
            __props__.__dict__["create_time"] = None
            __props__.__dict__["status"] = None
        super(Cluster, __self__).__init__(
            'alicloud:eflo/cluster:Cluster',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cluster_description: Optional[pulumi.Input[builtins.str]] = None,
            cluster_name: Optional[pulumi.Input[builtins.str]] = None,
            cluster_type: Optional[pulumi.Input[builtins.str]] = None,
            components: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ClusterComponentArgs', 'ClusterComponentArgsDict']]]]] = None,
            create_time: Optional[pulumi.Input[builtins.str]] = None,
            hpn_zone: Optional[pulumi.Input[builtins.str]] = None,
            ignore_failed_node_tasks: Optional[pulumi.Input[builtins.bool]] = None,
            networks: Optional[pulumi.Input[Union['ClusterNetworksArgs', 'ClusterNetworksArgsDict']]] = None,
            nimiz_vswitches: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            node_groups: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ClusterNodeGroupArgs', 'ClusterNodeGroupArgsDict']]]]] = None,
            open_eni_jumbo_frame: Optional[pulumi.Input[builtins.bool]] = None,
            resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None) -> 'Cluster':
        """
        Get an existing Cluster resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] cluster_description: cluster description
        :param pulumi.Input[builtins.str] cluster_name: ClusterName
        :param pulumi.Input[builtins.str] cluster_type: cluster type
        :param pulumi.Input[Sequence[pulumi.Input[Union['ClusterComponentArgs', 'ClusterComponentArgsDict']]]] components: Component (software instance) See `components` below.
        :param pulumi.Input[builtins.str] create_time: The creation time of the resource
        :param pulumi.Input[builtins.str] hpn_zone: Cluster Number
        :param pulumi.Input[builtins.bool] ignore_failed_node_tasks: Whether to allow skipping failed nodes. Default value: False
        :param pulumi.Input[Union['ClusterNetworksArgs', 'ClusterNetworksArgsDict']] networks: Network Information See `networks` below.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] nimiz_vswitches: Node virtual switch
        :param pulumi.Input[Sequence[pulumi.Input[Union['ClusterNodeGroupArgs', 'ClusterNodeGroupArgsDict']]]] node_groups: Node Group List See `node_groups` below.
        :param pulumi.Input[builtins.bool] open_eni_jumbo_frame: Whether the network interface supports jumbo frames
        :param pulumi.Input[builtins.str] resource_group_id: The ID of the resource group
        :param pulumi.Input[builtins.str] status: The status of the resource
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: tag
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ClusterState.__new__(_ClusterState)

        __props__.__dict__["cluster_description"] = cluster_description
        __props__.__dict__["cluster_name"] = cluster_name
        __props__.__dict__["cluster_type"] = cluster_type
        __props__.__dict__["components"] = components
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["hpn_zone"] = hpn_zone
        __props__.__dict__["ignore_failed_node_tasks"] = ignore_failed_node_tasks
        __props__.__dict__["networks"] = networks
        __props__.__dict__["nimiz_vswitches"] = nimiz_vswitches
        __props__.__dict__["node_groups"] = node_groups
        __props__.__dict__["open_eni_jumbo_frame"] = open_eni_jumbo_frame
        __props__.__dict__["resource_group_id"] = resource_group_id
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        return Cluster(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="clusterDescription")
    def cluster_description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        cluster description
        """
        return pulumi.get(self, "cluster_description")

    @property
    @pulumi.getter(name="clusterName")
    def cluster_name(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        ClusterName
        """
        return pulumi.get(self, "cluster_name")

    @property
    @pulumi.getter(name="clusterType")
    def cluster_type(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        cluster type
        """
        return pulumi.get(self, "cluster_type")

    @property
    @pulumi.getter
    def components(self) -> pulumi.Output[Optional[Sequence['outputs.ClusterComponent']]]:
        """
        Component (software instance) See `components` below.
        """
        return pulumi.get(self, "components")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.str]:
        """
        The creation time of the resource
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="hpnZone")
    def hpn_zone(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Cluster Number
        """
        return pulumi.get(self, "hpn_zone")

    @property
    @pulumi.getter(name="ignoreFailedNodeTasks")
    def ignore_failed_node_tasks(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Whether to allow skipping failed nodes. Default value: False
        """
        return pulumi.get(self, "ignore_failed_node_tasks")

    @property
    @pulumi.getter
    def networks(self) -> pulumi.Output[Optional['outputs.ClusterNetworks']]:
        """
        Network Information See `networks` below.
        """
        return pulumi.get(self, "networks")

    @property
    @pulumi.getter(name="nimizVswitches")
    def nimiz_vswitches(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        Node virtual switch
        """
        return pulumi.get(self, "nimiz_vswitches")

    @property
    @pulumi.getter(name="nodeGroups")
    def node_groups(self) -> pulumi.Output[Optional[Sequence['outputs.ClusterNodeGroup']]]:
        """
        Node Group List See `node_groups` below.
        """
        return pulumi.get(self, "node_groups")

    @property
    @pulumi.getter(name="openEniJumboFrame")
    def open_eni_jumbo_frame(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Whether the network interface supports jumbo frames
        """
        return pulumi.get(self, "open_eni_jumbo_frame")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the resource group
        """
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        The status of the resource
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, builtins.str]]]:
        """
        tag
        """
        return pulumi.get(self, "tags")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetBackupJobsResult',
    'AwaitableGetBackupJobsResult',
    'get_backup_jobs',
    'get_backup_jobs_output',
]

@pulumi.output_type
class GetBackupJobsResult:
    """
    A collection of values returned by getBackupJobs.
    """
    def __init__(__self__, filters=None, id=None, ids=None, jobs=None, output_file=None, sort_direction=None, source_type=None, status=None):
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if jobs and not isinstance(jobs, list):
            raise TypeError("Expected argument 'jobs' to be a list")
        pulumi.set(__self__, "jobs", jobs)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if sort_direction and not isinstance(sort_direction, str):
            raise TypeError("Expected argument 'sort_direction' to be a str")
        pulumi.set(__self__, "sort_direction", sort_direction)
        if source_type and not isinstance(source_type, str):
            raise TypeError("Expected argument 'source_type' to be a str")
        pulumi.set(__self__, "source_type", source_type)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetBackupJobsFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[builtins.str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter
    def jobs(self) -> Sequence['outputs.GetBackupJobsJobResult']:
        return pulumi.get(self, "jobs")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[builtins.str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="sortDirection")
    def sort_direction(self) -> Optional[builtins.str]:
        return pulumi.get(self, "sort_direction")

    @property
    @pulumi.getter(name="sourceType")
    def source_type(self) -> builtins.str:
        return pulumi.get(self, "source_type")

    @property
    @pulumi.getter
    def status(self) -> Optional[builtins.str]:
        return pulumi.get(self, "status")


class AwaitableGetBackupJobsResult(GetBackupJobsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetBackupJobsResult(
            filters=self.filters,
            id=self.id,
            ids=self.ids,
            jobs=self.jobs,
            output_file=self.output_file,
            sort_direction=self.sort_direction,
            source_type=self.source_type,
            status=self.status)


def get_backup_jobs(filters: Optional[Sequence[Union['GetBackupJobsFilterArgs', 'GetBackupJobsFilterArgsDict']]] = None,
                    ids: Optional[Sequence[builtins.str]] = None,
                    output_file: Optional[builtins.str] = None,
                    sort_direction: Optional[builtins.str] = None,
                    source_type: Optional[builtins.str] = None,
                    status: Optional[builtins.str] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetBackupJobsResult:
    """
    This data source provides the Hbr Backup Jobs of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.138.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default = alicloud.hbr.get_ecs_backup_plans(name_regex="plan-name")
    default_get_backup_jobs = alicloud.hbr.get_backup_jobs(source_type="ECS_FILE",
        filters=[
            {
                "key": "VaultId",
                "operator": "IN",
                "values": [default.plans[0].vault_id],
            },
            {
                "key": "InstanceId",
                "operator": "IN",
                "values": [default.plans[0].instance_id],
            },
            {
                "key": "CompleteTime",
                "operator": "BETWEEN",
                "values": [
                    "2021-08-23T14:17:15CST",
                    "2021-08-24T14:17:15CST",
                ],
            },
        ])
    example = alicloud.hbr.get_backup_jobs(source_type="ECS_FILE",
        status="COMPLETE",
        filters=[
            {
                "key": "VaultId",
                "operator": "IN",
                "values": [default.plans[0].vault_id],
            },
            {
                "key": "InstanceId",
                "operator": "IN",
                "values": [default.plans[0].instance_id],
            },
            {
                "key": "CompleteTime",
                "operator": "LESS_THAN",
                "values": ["2021-10-20T20:20:20CST"],
            },
        ])
    pulumi.export("alicloudHbrBackupJobsDefault1", default_get_backup_jobs.jobs[0].id)
    pulumi.export("alicloudHbrBackupJobsExample1", example.jobs[0].id)
    ```


    :param Sequence[builtins.str] ids: A list of Backup Job IDs.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.str sort_direction: The sort direction, sort results by ascending or descending order based on the value jobs id. Valid values: `ASCEND`, `DESCEND`.
    :param builtins.str source_type: The type of data source. Valid values: `ECS_FILE`, `NAS`, `OSS`, `OTS`, `UDM_ECS`, `UDM_ECS_DISK`.
    :param builtins.str status: The status of backup job. Valid values: `COMPLETE`, `PARTIAL_COMPLETE`, `FAILED`, `UNAVAILABLE`.
    """
    __args__ = dict()
    __args__['filters'] = filters
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['sortDirection'] = sort_direction
    __args__['sourceType'] = source_type
    __args__['status'] = status
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:hbr/getBackupJobs:getBackupJobs', __args__, opts=opts, typ=GetBackupJobsResult).value

    return AwaitableGetBackupJobsResult(
        filters=pulumi.get(__ret__, 'filters'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        jobs=pulumi.get(__ret__, 'jobs'),
        output_file=pulumi.get(__ret__, 'output_file'),
        sort_direction=pulumi.get(__ret__, 'sort_direction'),
        source_type=pulumi.get(__ret__, 'source_type'),
        status=pulumi.get(__ret__, 'status'))
def get_backup_jobs_output(filters: Optional[pulumi.Input[Optional[Sequence[Union['GetBackupJobsFilterArgs', 'GetBackupJobsFilterArgsDict']]]]] = None,
                           ids: Optional[pulumi.Input[Optional[Sequence[builtins.str]]]] = None,
                           output_file: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                           sort_direction: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                           source_type: Optional[pulumi.Input[builtins.str]] = None,
                           status: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                           opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetBackupJobsResult]:
    """
    This data source provides the Hbr Backup Jobs of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.138.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default = alicloud.hbr.get_ecs_backup_plans(name_regex="plan-name")
    default_get_backup_jobs = alicloud.hbr.get_backup_jobs(source_type="ECS_FILE",
        filters=[
            {
                "key": "VaultId",
                "operator": "IN",
                "values": [default.plans[0].vault_id],
            },
            {
                "key": "InstanceId",
                "operator": "IN",
                "values": [default.plans[0].instance_id],
            },
            {
                "key": "CompleteTime",
                "operator": "BETWEEN",
                "values": [
                    "2021-08-23T14:17:15CST",
                    "2021-08-24T14:17:15CST",
                ],
            },
        ])
    example = alicloud.hbr.get_backup_jobs(source_type="ECS_FILE",
        status="COMPLETE",
        filters=[
            {
                "key": "VaultId",
                "operator": "IN",
                "values": [default.plans[0].vault_id],
            },
            {
                "key": "InstanceId",
                "operator": "IN",
                "values": [default.plans[0].instance_id],
            },
            {
                "key": "CompleteTime",
                "operator": "LESS_THAN",
                "values": ["2021-10-20T20:20:20CST"],
            },
        ])
    pulumi.export("alicloudHbrBackupJobsDefault1", default_get_backup_jobs.jobs[0].id)
    pulumi.export("alicloudHbrBackupJobsExample1", example.jobs[0].id)
    ```


    :param Sequence[builtins.str] ids: A list of Backup Job IDs.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.str sort_direction: The sort direction, sort results by ascending or descending order based on the value jobs id. Valid values: `ASCEND`, `DESCEND`.
    :param builtins.str source_type: The type of data source. Valid values: `ECS_FILE`, `NAS`, `OSS`, `OTS`, `UDM_ECS`, `UDM_ECS_DISK`.
    :param builtins.str status: The status of backup job. Valid values: `COMPLETE`, `PARTIAL_COMPLETE`, `FAILED`, `UNAVAILABLE`.
    """
    __args__ = dict()
    __args__['filters'] = filters
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['sortDirection'] = sort_direction
    __args__['sourceType'] = source_type
    __args__['status'] = status
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:hbr/getBackupJobs:getBackupJobs', __args__, opts=opts, typ=GetBackupJobsResult)
    return __ret__.apply(lambda __response__: GetBackupJobsResult(
        filters=pulumi.get(__response__, 'filters'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        jobs=pulumi.get(__response__, 'jobs'),
        output_file=pulumi.get(__response__, 'output_file'),
        sort_direction=pulumi.get(__response__, 'sort_direction'),
        source_type=pulumi.get(__response__, 'source_type'),
        status=pulumi.get(__response__, 'status')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['QuotaArgs', 'Quota']

@pulumi.input_type
class QuotaArgs:
    def __init__(__self__, *,
                 commodity_code: pulumi.Input[builtins.str],
                 payment_type: pulumi.Input[builtins.str],
                 commodity_data: Optional[pulumi.Input[builtins.str]] = None,
                 part_nick_name: Optional[pulumi.Input[builtins.str]] = None,
                 sub_quota_info_lists: Optional[pulumi.Input[Sequence[pulumi.Input['QuotaSubQuotaInfoListArgs']]]] = None):
        """
        The set of arguments for constructing a Quota resource.
        :param pulumi.Input[builtins.str] commodity_code: Valid values: odps_intl/odpsplus_intl/odps/odpsplus
               - *NOTE:** --odps_intl: International Station standard post-payment -- odpsplus_intl: International Station standard pre-payment -- odps: China Station standard post-payment -- odpsplus: China Station standard pre-payment
        :param pulumi.Input[builtins.str] payment_type: Payment type. Valid values: Subscription/PayAsYouGo
               
               > **NOTE:** -- PayAsYouGo only needs to be opened once per region
        :param pulumi.Input[builtins.str] commodity_data: Define quota rules when creating quotas, for example:{"CU":50,"ord_time":"1:Month","autoRenew":false}.
               CU (minimum quota resource size is 50)
               ord_time 1:Month/Year (1 means quantity: Month/Year is the unit)
               autoRenew (whether to enable automatic renewal)
               If PaymentType is PayAsYouGo, you do not need to fill in
        :param pulumi.Input[builtins.str] part_nick_name: Quota partial nickname, supports English letters and numbers, up to 24 characters
               
               > **NOTE:** If PaymentType is PayAsYouGo, you do not need to fill it in
        :param pulumi.Input[Sequence[pulumi.Input['QuotaSubQuotaInfoListArgs']]] sub_quota_info_lists: Secondary Quota list
               
               > **NOTE:** -- Add: If the configuration contains a second-level Quota that does not exist, a second-level Quota is added. -- Delete: If the configuration does not contain the existing secondary Quota, it will be deleted. -- Modify: If the configuration is inconsistent with the existing secondary Quota configuration parameters, the secondary Quota configuration will be updated. -- The default secondary Quota must be configured and cannot be deleted.
               See `sub_quota_info_list` below.
        """
        pulumi.set(__self__, "commodity_code", commodity_code)
        pulumi.set(__self__, "payment_type", payment_type)
        if commodity_data is not None:
            pulumi.set(__self__, "commodity_data", commodity_data)
        if part_nick_name is not None:
            pulumi.set(__self__, "part_nick_name", part_nick_name)
        if sub_quota_info_lists is not None:
            pulumi.set(__self__, "sub_quota_info_lists", sub_quota_info_lists)

    @property
    @pulumi.getter(name="commodityCode")
    def commodity_code(self) -> pulumi.Input[builtins.str]:
        """
        Valid values: odps_intl/odpsplus_intl/odps/odpsplus
        - *NOTE:** --odps_intl: International Station standard post-payment -- odpsplus_intl: International Station standard pre-payment -- odps: China Station standard post-payment -- odpsplus: China Station standard pre-payment
        """
        return pulumi.get(self, "commodity_code")

    @commodity_code.setter
    def commodity_code(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "commodity_code", value)

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> pulumi.Input[builtins.str]:
        """
        Payment type. Valid values: Subscription/PayAsYouGo

        > **NOTE:** -- PayAsYouGo only needs to be opened once per region
        """
        return pulumi.get(self, "payment_type")

    @payment_type.setter
    def payment_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "payment_type", value)

    @property
    @pulumi.getter(name="commodityData")
    def commodity_data(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Define quota rules when creating quotas, for example:{"CU":50,"ord_time":"1:Month","autoRenew":false}.
        CU (minimum quota resource size is 50)
        ord_time 1:Month/Year (1 means quantity: Month/Year is the unit)
        autoRenew (whether to enable automatic renewal)
        If PaymentType is PayAsYouGo, you do not need to fill in
        """
        return pulumi.get(self, "commodity_data")

    @commodity_data.setter
    def commodity_data(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "commodity_data", value)

    @property
    @pulumi.getter(name="partNickName")
    def part_nick_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Quota partial nickname, supports English letters and numbers, up to 24 characters

        > **NOTE:** If PaymentType is PayAsYouGo, you do not need to fill it in
        """
        return pulumi.get(self, "part_nick_name")

    @part_nick_name.setter
    def part_nick_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "part_nick_name", value)

    @property
    @pulumi.getter(name="subQuotaInfoLists")
    def sub_quota_info_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['QuotaSubQuotaInfoListArgs']]]]:
        """
        Secondary Quota list

        > **NOTE:** -- Add: If the configuration contains a second-level Quota that does not exist, a second-level Quota is added. -- Delete: If the configuration does not contain the existing secondary Quota, it will be deleted. -- Modify: If the configuration is inconsistent with the existing secondary Quota configuration parameters, the secondary Quota configuration will be updated. -- The default secondary Quota must be configured and cannot be deleted.
        See `sub_quota_info_list` below.
        """
        return pulumi.get(self, "sub_quota_info_lists")

    @sub_quota_info_lists.setter
    def sub_quota_info_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['QuotaSubQuotaInfoListArgs']]]]):
        pulumi.set(self, "sub_quota_info_lists", value)


@pulumi.input_type
class _QuotaState:
    def __init__(__self__, *,
                 commodity_code: Optional[pulumi.Input[builtins.str]] = None,
                 commodity_data: Optional[pulumi.Input[builtins.str]] = None,
                 part_nick_name: Optional[pulumi.Input[builtins.str]] = None,
                 payment_type: Optional[pulumi.Input[builtins.str]] = None,
                 sub_quota_info_lists: Optional[pulumi.Input[Sequence[pulumi.Input['QuotaSubQuotaInfoListArgs']]]] = None):
        """
        Input properties used for looking up and filtering Quota resources.
        :param pulumi.Input[builtins.str] commodity_code: Valid values: odps_intl/odpsplus_intl/odps/odpsplus
               - *NOTE:** --odps_intl: International Station standard post-payment -- odpsplus_intl: International Station standard pre-payment -- odps: China Station standard post-payment -- odpsplus: China Station standard pre-payment
        :param pulumi.Input[builtins.str] commodity_data: Define quota rules when creating quotas, for example:{"CU":50,"ord_time":"1:Month","autoRenew":false}.
               CU (minimum quota resource size is 50)
               ord_time 1:Month/Year (1 means quantity: Month/Year is the unit)
               autoRenew (whether to enable automatic renewal)
               If PaymentType is PayAsYouGo, you do not need to fill in
        :param pulumi.Input[builtins.str] part_nick_name: Quota partial nickname, supports English letters and numbers, up to 24 characters
               
               > **NOTE:** If PaymentType is PayAsYouGo, you do not need to fill it in
        :param pulumi.Input[builtins.str] payment_type: Payment type. Valid values: Subscription/PayAsYouGo
               
               > **NOTE:** -- PayAsYouGo only needs to be opened once per region
        :param pulumi.Input[Sequence[pulumi.Input['QuotaSubQuotaInfoListArgs']]] sub_quota_info_lists: Secondary Quota list
               
               > **NOTE:** -- Add: If the configuration contains a second-level Quota that does not exist, a second-level Quota is added. -- Delete: If the configuration does not contain the existing secondary Quota, it will be deleted. -- Modify: If the configuration is inconsistent with the existing secondary Quota configuration parameters, the secondary Quota configuration will be updated. -- The default secondary Quota must be configured and cannot be deleted.
               See `sub_quota_info_list` below.
        """
        if commodity_code is not None:
            pulumi.set(__self__, "commodity_code", commodity_code)
        if commodity_data is not None:
            pulumi.set(__self__, "commodity_data", commodity_data)
        if part_nick_name is not None:
            pulumi.set(__self__, "part_nick_name", part_nick_name)
        if payment_type is not None:
            pulumi.set(__self__, "payment_type", payment_type)
        if sub_quota_info_lists is not None:
            pulumi.set(__self__, "sub_quota_info_lists", sub_quota_info_lists)

    @property
    @pulumi.getter(name="commodityCode")
    def commodity_code(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Valid values: odps_intl/odpsplus_intl/odps/odpsplus
        - *NOTE:** --odps_intl: International Station standard post-payment -- odpsplus_intl: International Station standard pre-payment -- odps: China Station standard post-payment -- odpsplus: China Station standard pre-payment
        """
        return pulumi.get(self, "commodity_code")

    @commodity_code.setter
    def commodity_code(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "commodity_code", value)

    @property
    @pulumi.getter(name="commodityData")
    def commodity_data(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Define quota rules when creating quotas, for example:{"CU":50,"ord_time":"1:Month","autoRenew":false}.
        CU (minimum quota resource size is 50)
        ord_time 1:Month/Year (1 means quantity: Month/Year is the unit)
        autoRenew (whether to enable automatic renewal)
        If PaymentType is PayAsYouGo, you do not need to fill in
        """
        return pulumi.get(self, "commodity_data")

    @commodity_data.setter
    def commodity_data(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "commodity_data", value)

    @property
    @pulumi.getter(name="partNickName")
    def part_nick_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Quota partial nickname, supports English letters and numbers, up to 24 characters

        > **NOTE:** If PaymentType is PayAsYouGo, you do not need to fill it in
        """
        return pulumi.get(self, "part_nick_name")

    @part_nick_name.setter
    def part_nick_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "part_nick_name", value)

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Payment type. Valid values: Subscription/PayAsYouGo

        > **NOTE:** -- PayAsYouGo only needs to be opened once per region
        """
        return pulumi.get(self, "payment_type")

    @payment_type.setter
    def payment_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "payment_type", value)

    @property
    @pulumi.getter(name="subQuotaInfoLists")
    def sub_quota_info_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['QuotaSubQuotaInfoListArgs']]]]:
        """
        Secondary Quota list

        > **NOTE:** -- Add: If the configuration contains a second-level Quota that does not exist, a second-level Quota is added. -- Delete: If the configuration does not contain the existing secondary Quota, it will be deleted. -- Modify: If the configuration is inconsistent with the existing secondary Quota configuration parameters, the secondary Quota configuration will be updated. -- The default secondary Quota must be configured and cannot be deleted.
        See `sub_quota_info_list` below.
        """
        return pulumi.get(self, "sub_quota_info_lists")

    @sub_quota_info_lists.setter
    def sub_quota_info_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['QuotaSubQuotaInfoListArgs']]]]):
        pulumi.set(self, "sub_quota_info_lists", value)


@pulumi.type_token("alicloud:maxcompute/quota:Quota")
class Quota(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 commodity_code: Optional[pulumi.Input[builtins.str]] = None,
                 commodity_data: Optional[pulumi.Input[builtins.str]] = None,
                 part_nick_name: Optional[pulumi.Input[builtins.str]] = None,
                 payment_type: Optional[pulumi.Input[builtins.str]] = None,
                 sub_quota_info_lists: Optional[pulumi.Input[Sequence[pulumi.Input[Union['QuotaSubQuotaInfoListArgs', 'QuotaSubQuotaInfoListArgsDict']]]]] = None,
                 __props__=None):
        """
        ## Import

        Max Compute Quota can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:maxcompute/quota:Quota example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] commodity_code: Valid values: odps_intl/odpsplus_intl/odps/odpsplus
               - *NOTE:** --odps_intl: International Station standard post-payment -- odpsplus_intl: International Station standard pre-payment -- odps: China Station standard post-payment -- odpsplus: China Station standard pre-payment
        :param pulumi.Input[builtins.str] commodity_data: Define quota rules when creating quotas, for example:{"CU":50,"ord_time":"1:Month","autoRenew":false}.
               CU (minimum quota resource size is 50)
               ord_time 1:Month/Year (1 means quantity: Month/Year is the unit)
               autoRenew (whether to enable automatic renewal)
               If PaymentType is PayAsYouGo, you do not need to fill in
        :param pulumi.Input[builtins.str] part_nick_name: Quota partial nickname, supports English letters and numbers, up to 24 characters
               
               > **NOTE:** If PaymentType is PayAsYouGo, you do not need to fill it in
        :param pulumi.Input[builtins.str] payment_type: Payment type. Valid values: Subscription/PayAsYouGo
               
               > **NOTE:** -- PayAsYouGo only needs to be opened once per region
        :param pulumi.Input[Sequence[pulumi.Input[Union['QuotaSubQuotaInfoListArgs', 'QuotaSubQuotaInfoListArgsDict']]]] sub_quota_info_lists: Secondary Quota list
               
               > **NOTE:** -- Add: If the configuration contains a second-level Quota that does not exist, a second-level Quota is added. -- Delete: If the configuration does not contain the existing secondary Quota, it will be deleted. -- Modify: If the configuration is inconsistent with the existing secondary Quota configuration parameters, the secondary Quota configuration will be updated. -- The default secondary Quota must be configured and cannot be deleted.
               See `sub_quota_info_list` below.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: QuotaArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Import

        Max Compute Quota can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:maxcompute/quota:Quota example <id>
        ```

        :param str resource_name: The name of the resource.
        :param QuotaArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(QuotaArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 commodity_code: Optional[pulumi.Input[builtins.str]] = None,
                 commodity_data: Optional[pulumi.Input[builtins.str]] = None,
                 part_nick_name: Optional[pulumi.Input[builtins.str]] = None,
                 payment_type: Optional[pulumi.Input[builtins.str]] = None,
                 sub_quota_info_lists: Optional[pulumi.Input[Sequence[pulumi.Input[Union['QuotaSubQuotaInfoListArgs', 'QuotaSubQuotaInfoListArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = QuotaArgs.__new__(QuotaArgs)

            if commodity_code is None and not opts.urn:
                raise TypeError("Missing required property 'commodity_code'")
            __props__.__dict__["commodity_code"] = commodity_code
            __props__.__dict__["commodity_data"] = commodity_data
            __props__.__dict__["part_nick_name"] = part_nick_name
            if payment_type is None and not opts.urn:
                raise TypeError("Missing required property 'payment_type'")
            __props__.__dict__["payment_type"] = payment_type
            __props__.__dict__["sub_quota_info_lists"] = sub_quota_info_lists
        super(Quota, __self__).__init__(
            'alicloud:maxcompute/quota:Quota',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            commodity_code: Optional[pulumi.Input[builtins.str]] = None,
            commodity_data: Optional[pulumi.Input[builtins.str]] = None,
            part_nick_name: Optional[pulumi.Input[builtins.str]] = None,
            payment_type: Optional[pulumi.Input[builtins.str]] = None,
            sub_quota_info_lists: Optional[pulumi.Input[Sequence[pulumi.Input[Union['QuotaSubQuotaInfoListArgs', 'QuotaSubQuotaInfoListArgsDict']]]]] = None) -> 'Quota':
        """
        Get an existing Quota resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] commodity_code: Valid values: odps_intl/odpsplus_intl/odps/odpsplus
               - *NOTE:** --odps_intl: International Station standard post-payment -- odpsplus_intl: International Station standard pre-payment -- odps: China Station standard post-payment -- odpsplus: China Station standard pre-payment
        :param pulumi.Input[builtins.str] commodity_data: Define quota rules when creating quotas, for example:{"CU":50,"ord_time":"1:Month","autoRenew":false}.
               CU (minimum quota resource size is 50)
               ord_time 1:Month/Year (1 means quantity: Month/Year is the unit)
               autoRenew (whether to enable automatic renewal)
               If PaymentType is PayAsYouGo, you do not need to fill in
        :param pulumi.Input[builtins.str] part_nick_name: Quota partial nickname, supports English letters and numbers, up to 24 characters
               
               > **NOTE:** If PaymentType is PayAsYouGo, you do not need to fill it in
        :param pulumi.Input[builtins.str] payment_type: Payment type. Valid values: Subscription/PayAsYouGo
               
               > **NOTE:** -- PayAsYouGo only needs to be opened once per region
        :param pulumi.Input[Sequence[pulumi.Input[Union['QuotaSubQuotaInfoListArgs', 'QuotaSubQuotaInfoListArgsDict']]]] sub_quota_info_lists: Secondary Quota list
               
               > **NOTE:** -- Add: If the configuration contains a second-level Quota that does not exist, a second-level Quota is added. -- Delete: If the configuration does not contain the existing secondary Quota, it will be deleted. -- Modify: If the configuration is inconsistent with the existing secondary Quota configuration parameters, the secondary Quota configuration will be updated. -- The default secondary Quota must be configured and cannot be deleted.
               See `sub_quota_info_list` below.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _QuotaState.__new__(_QuotaState)

        __props__.__dict__["commodity_code"] = commodity_code
        __props__.__dict__["commodity_data"] = commodity_data
        __props__.__dict__["part_nick_name"] = part_nick_name
        __props__.__dict__["payment_type"] = payment_type
        __props__.__dict__["sub_quota_info_lists"] = sub_quota_info_lists
        return Quota(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="commodityCode")
    def commodity_code(self) -> pulumi.Output[builtins.str]:
        """
        Valid values: odps_intl/odpsplus_intl/odps/odpsplus
        - *NOTE:** --odps_intl: International Station standard post-payment -- odpsplus_intl: International Station standard pre-payment -- odps: China Station standard post-payment -- odpsplus: China Station standard pre-payment
        """
        return pulumi.get(self, "commodity_code")

    @property
    @pulumi.getter(name="commodityData")
    def commodity_data(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Define quota rules when creating quotas, for example:{"CU":50,"ord_time":"1:Month","autoRenew":false}.
        CU (minimum quota resource size is 50)
        ord_time 1:Month/Year (1 means quantity: Month/Year is the unit)
        autoRenew (whether to enable automatic renewal)
        If PaymentType is PayAsYouGo, you do not need to fill in
        """
        return pulumi.get(self, "commodity_data")

    @property
    @pulumi.getter(name="partNickName")
    def part_nick_name(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Quota partial nickname, supports English letters and numbers, up to 24 characters

        > **NOTE:** If PaymentType is PayAsYouGo, you do not need to fill it in
        """
        return pulumi.get(self, "part_nick_name")

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> pulumi.Output[builtins.str]:
        """
        Payment type. Valid values: Subscription/PayAsYouGo

        > **NOTE:** -- PayAsYouGo only needs to be opened once per region
        """
        return pulumi.get(self, "payment_type")

    @property
    @pulumi.getter(name="subQuotaInfoLists")
    def sub_quota_info_lists(self) -> pulumi.Output[Sequence['outputs.QuotaSubQuotaInfoList']]:
        """
        Secondary Quota list

        > **NOTE:** -- Add: If the configuration contains a second-level Quota that does not exist, a second-level Quota is added. -- Delete: If the configuration does not contain the existing secondary Quota, it will be deleted. -- Modify: If the configuration is inconsistent with the existing secondary Quota configuration parameters, the secondary Quota configuration will be updated. -- The default secondary Quota must be configured and cannot be deleted.
        See `sub_quota_info_list` below.
        """
        return pulumi.get(self, "sub_quota_info_lists")

